TimeAgoLocaleFunctions class abstract

Plural, number, and date operations used by LocaleConfig.

Implementers

Constructors

TimeAgoLocaleFunctions()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatMonthDay(DateTime value) String
formatNumber(num value) String
formatYearMonthDay(DateTime value) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolvePlural(num value) TimeAgoPluralCategory
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited