TimeAgoUnitLabels class

Directionless unit labels used to compose multi-unit output.

Constructors

TimeAgoUnitLabels({required TimeAgoPluralLabels second, required TimeAgoPluralLabels minute, required TimeAgoPluralLabels hour, required TimeAgoPluralLabels day, required TimeAgoPluralLabels week, required TimeAgoPluralLabels month, required TimeAgoPluralLabels quarter, required TimeAgoPluralLabels year})
const

Properties

day TimeAgoPluralLabels
final
hashCode int
The hash code for this object.
no setterinherited
hour TimeAgoPluralLabels
final
minute TimeAgoPluralLabels
final
month TimeAgoPluralLabels
final
quarter TimeAgoPluralLabels
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
second TimeAgoPluralLabels
final
week TimeAgoPluralLabels
final
year TimeAgoPluralLabels
final

Methods

copyWith({TimeAgoPluralLabels? second, TimeAgoPluralLabels? minute, TimeAgoPluralLabels? hour, TimeAgoPluralLabels? day, TimeAgoPluralLabels? week, TimeAgoPluralLabels? month, TimeAgoPluralLabels? quarter, TimeAgoPluralLabels? year}) TimeAgoUnitLabels
forUnit(TimeAgoUnit unit) TimeAgoPluralLabels
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited