steps top-level constant

List<TimeAgoStep> const steps

Intl calendar-oriented steps for activity feeds and message lists.

Values through one minute render the locale's current now label. Values through 30 minutes use localized relative minutes. Older values render the locale's named yesterday, today, or tomorrow, a localized month-day in the current year, or a localized year-month-day in other years, combined with a localized clock without seconds.

Implementation

const steps = <TimeAgoStep>[
  TimeAgoStep.custom(
    unit: TimeAgoUnit.now,
    formatter: _now,
    nextUpdate: _neverUpdates,
  ),
  TimeAgoStep.unit(
    TimeAgoUnit.minute,
    minTime: _afterOneMinute,
  ),
  TimeAgoStep.custom(
    minTime: _afterThirtyMinutes,
    formatter: _dateTime,
    nextUpdate: _nextUpdate,
  ),
];