TimeAgoProvider class
Supplies nested, non-global defaults and a shared update scheduler.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TimeAgoProvider
Constructors
-
TimeAgoProvider({Key? key, required LocaleConfig locale, TimeAgoFormat format = TimeAgoFormat.long, bool? directional, bool? future, List<
TimeAgoStep> steps = TimeAgoSteps.fromMinuteNow, List<TimeAgoUnit> multiUnits = TimeAgoUnit.defaults, TimeAgoStep? cutoffStep, TimeAgoLocaleFunctions? fallbackFunctions, TimeAgoScheduler? scheduler, DateTime? frozenAt, Duration unknownUpdateInterval = const Duration(minutes: 1), required Widget child}) -
const
Properties
- child → Widget
-
final
- cutoffStep → TimeAgoStep?
-
The standalone cutoff supplied to descendant formatting calls.
final
- directional → bool?
-
final
- fallbackFunctions → TimeAgoLocaleFunctions?
-
Non-Intl operations used when this locale's Intl data is unavailable.
final
- format → TimeAgoFormat
-
final
- frozenAt → DateTime?
-
final
- future → bool?
-
Forces future grammar for descendant extensions and widgets when true.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- locale → LocaleConfig
-
final
-
multiUnits
→ List<
TimeAgoUnit> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduler → TimeAgoScheduler?
-
final
-
steps
→ List<
TimeAgoStep> -
final
- unknownUpdateInterval → Duration
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TimeAgoProvider> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
maybeOf(
BuildContext context) → TimeAgoProviderData? -
of(
BuildContext context) → TimeAgoProviderData