Immutable, reusable relative-time step presets without date formatting.
This module is exported by package:any_timeago/any_timeago.dart.
Date-formatting presets are opt-in modules under package:any_timeago/steps.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
approximate
→ const List<
TimeAgoStep> -
Fuzzy thresholds compatible with the intent of JavaScript
approximate: moment, minute, five-minute increments, half-hour, hour, day, week, month, and year. -
fromMinute
→ const List<
TimeAgoStep> -
fromMinuteNow
→ const List<
TimeAgoStep> -
precise
→ const List<
TimeAgoStep> -
preciseNow
→ const List<
TimeAgoStep>